==> v9.2.0.zip: barker/bookie/src/app/sales/sales.module.ts <==
import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { FlexLayoutModule } from '@angular/flex-layout';
import { ReactiveFormsModule } from '@angular/forms';
import { MatBadgeModule } from '@angular/material/badge';
import { MatButtonModule } from '@angular/material/button';
import { MatButtonToggleModule } from '@angular/material/button-toggle';
import { MatCardModule } from '@angular/material/card';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatChipsModule } from '@angular/material/chips';
import { MatOptionModule, MatRippleModule } from '@angular/material/core';
import { MatDialogModule } from '@angular/material/dialog';
import { MatDividerModule } from '@angular/material/divider';
import { MatIconModule } from '@angular/material/icon';
import { MatInputModule } from '@angular/material/input';
import { MatSelectModule } from '@angular/material/select';
import { MatTableModule } from '@angular/material/table';
import { MatTabsModule } from '@angular/material/tabs';
import { MatTooltipModule } from '@angular/material/tooltip';

import { SharedModule } from '../shared/shared.module';

import { BillNumberComponent } from './bill-number/bill-number.component';
import { BillTypeComponent } from './bill-type/bill-type.component';
import { BillService } from './bill.service';
import { BillsComponent } from './bills/bills.component';
import { DiscountComponent } from './discount/discount.component';
import { SalesHomeComponent } from './home/sales-home.component';
import { MenuCategoriesComponent } from './menu-categories/menu-categories.component';
import { ModifiersComponent } from './modifiers/modifiers.component';
import { PaxComponent } from './pax/pax.component';
import { ProductsComponent } from './products/products.component';
import { QuantityComponent } from './quantity/quantity.component';
import { ReasonComponent } from './reason/reason.component';
import { ReceivePaymentComponent } from './receive-payment/receive-payment.component';
import { RunningTablesComponent } from './running-tables/running-tables.component';
import { SalesRoutingModule } from './sales-routing.module';
import { SplitBillComponent } from './split-bill/split-bill.component';
import { TablesDialogComponent } from './tables-dialog/tables-dialog.component';

@NgModule({
  providers: [BillService],
  declarations: [
    BillsComponent,
    BillNumberComponent,
    BillTypeComponent,
    DiscountComponent,
    MenuCategoriesComponent,
    ModifiersComponent,
    PaxComponent,
    ProductsComponent,
    QuantityComponent,
    ReceivePaymentComponent,
    RunningTablesComponent,
    SplitBillComponent,
    SalesHomeComponent,
    TablesDialogComponent,
    ReasonComponent,
  ],
  imports: [
    CommonModule,
    FlexLayoutModule,
    ReactiveFormsModule,
    MatBadgeModule,
    MatButtonModule,
    MatButtonToggleModule,
    MatCardModule,
    MatCheckboxModule,
    MatChipsModule,
    MatDialogModule,
    MatDividerModule,
    MatOptionModule,
    MatIconModule,
    MatInputModule,
    MatRippleModule,
    MatTableModule,
    MatTabsModule,
    MatTooltipModule,
    SharedModule,
    SalesRoutingModule,
    MatSelectModule,
  ],
})
export class SalesModule {}

==> v10.3.3.zip: barker/bookie/src/app/sales/sales.module.ts <==
import { CommonModule } from '@angular/common';
import { NgModule } from '@angular/core';
import { FlexLayoutModule } from '@angular/flex-layout';
import { ReactiveFormsModule } from '@angular/forms';
import { MatAutocompleteModule } from '@angular/material/autocomplete';
import { MatBadgeModule } from '@angular/material/badge';
import { MatButtonModule } from '@angular/material/button';
import { MatButtonToggleModule } from '@angular/material/button-toggle';
import { MatCardModule } from '@angular/material/card';
import { MatCheckboxModule } from '@angular/material/checkbox';
import { MatChipsModule } from '@angular/material/chips';
import { MatOptionModule, MatRippleModule } from '@angular/material/core';
import { MatDialogModule } from '@angular/material/dialog';
import { MatDividerModule } from '@angular/material/divider';
import { MatIconModule } from '@angular/material/icon';
import { MatInputModule } from '@angular/material/input';
import { MatSelectModule } from '@angular/material/select';
import { MatTableModule } from '@angular/material/table';
import { MatTabsModule } from '@angular/material/tabs';
import { MatTooltipModule } from '@angular/material/tooltip';

import { SharedModule } from '../shared/shared.module';

import { BillNumberComponent } from './bill-number/bill-number.component';
import { BillTypeComponent } from './bill-type/bill-type.component';
import { BillService } from './bill.service';
import { BillsComponent } from './bills/bills.component';
import { CanDeactivateBillGuard } from './can-deactivate-bill.guard';
import { ChooseCustomerComponent } from './choose-customer/choose-customer.component';
import { DiscountComponent } from './discount/discount.component';
import { SalesHomeComponent } from './home/sales-home.component';
import { MenuCategoriesComponent } from './menu-categories/menu-categories.component';
import { ModifiersComponent } from './modifiers/modifiers.component';
import { PaxComponent } from './pax/pax.component';
import { ProductsComponent } from './products/products.component';
import { QuantityComponent } from './quantity/quantity.component';
import { ReasonComponent } from './reason/reason.component';
import { ReceivePaymentComponent } from './receive-payment/receive-payment.component';
import { RunningTablesComponent } from './running-tables/running-tables.component';
import { SalesRoutingModule } from './sales-routing.module';
import { SplitBillComponent } from './split-bill/split-bill.component';
import { TablesDialogComponent } from './tables-dialog/tables-dialog.component';

@NgModule({
  providers: [BillService, CanDeactivateBillGuard],
  declarations: [
    BillsComponent,
    BillNumberComponent,
    BillTypeComponent,
    DiscountComponent,
    MenuCategoriesComponent,
    ModifiersComponent,
    PaxComponent,
    ChooseCustomerComponent,
    ProductsComponent,
    QuantityComponent,
    ReceivePaymentComponent,
    RunningTablesComponent,
    SplitBillComponent,
    SalesHomeComponent,
    TablesDialogComponent,
    ReasonComponent,
  ],
  imports: [
    CommonModule,
    FlexLayoutModule,
    ReactiveFormsModule,
    MatBadgeModule,
    MatButtonModule,
    MatButtonToggleModule,
    MatCardModule,
    MatCheckboxModule,
    MatChipsModule,
    MatDialogModule,
    MatDividerModule,
    MatOptionModule,
    MatIconModule,
    MatInputModule,
    MatRippleModule,
    MatTableModule,
    MatTabsModule,
    MatTooltipModule,
    SharedModule,
    SalesRoutingModule,
    MatSelectModule,
    MatAutocompleteModule,
  ],
})
export class SalesModule {}
